<!--
This README describes the package. If you publish this package to pub.dev,
this README's contents appear on the landing page for your package.

For information about how to write a good package README, see the guide for
[writing package pages](https://dart.dev/guides/libraries/writing-package-pages).

For general information about developing packages, see the Dart guide for
[creating packages](https://dart.dev/guides/libraries/create-library-packages)
and the Flutter guide for
[developing packages and plugins](https://flutter.dev/developing-packages).
-->

## 开始使用

```yaml
dependencies:
  clx_webview_flutter:
    git:
      url: https://t.clxkj.cn/openSourceLibrary/clx_webview_flutter.git
```

## Usage

### 导入

在使用之前，请确保您已经导入了`clx_webview_flutter`包。
```dart
import 'package:clx_webview_flutter/clx_webview_flutter.dart';
```
### 初始化

#### loadRequest:在使用`CustomController`之前，您需要先初始化它。您可以通过调用`loadRequest`方法来加载一个请求。
```dart
final CustomController customController = CustomController.loadRequest(
            requestedUrl: Uri.parse(uri), title: 'Captcha');
```
#### loadFile:如果您想加载一个本地html，您可以使用`loadFile`方法。
```dart
final CustomController customController = CustomController.loadFile(absoluteFilePath: 'c://path/to/your/file.html');
```
#### loadHtmlString:如果您想加载一个html字符串，您可以使用`loadHtmlString`方法。
```dart
final CustomController customController = CustomController.loadHtmlString(htmlString);
```
#### 添加JavaScript注入
```dart
Future<bool> setJavaScriptChannels(JavaScriptChannel channel)
```
#### 设置标题
```dart
Future<void> setTitle(String title)
```
#### 设置标题样式
```dart
Future<bool> setAppBarTextStyle(TextStyle? style)
```
### 使用
#### 添加WebView

使用CustomWebView组件来显示WebView。
```dart
import 'package:flutter/material.dart';

import '../clx_webview_flutter.dart';

abstract class CaptchaUtil {
  static Future<bool>? generateCaptcha(
      {required BuildContext context,
      required String uri,
      required Future<bool> Function(JavaScriptMessage message)
          onCaptchaGenerated}) async {
    return await Navigator.push(context, PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) {
        final CustomController customController = CustomController.loadRequest(
            requestedUrl: Uri.parse(uri), title: '验证码');
        customController.setJavaScriptChannels(JavaScriptChannel(
          name: 'H5CallFlutterInterface',
          callback: (message) async {
            if (!context.mounted) {
              return CLXResult.fail(Exception('context not mounted'));
            }
            final result = await onCaptchaGenerated(message);
            if (result) {
              Navigator.pop(context, true);
              return CLXResult.fail(Exception('captcha failed'));
            } else {
              customController.controller.reload();
              return CLXResult.succ(result);
            }
          },
        ));
        return CustomWebView(customController: customController);
      },
    ));
  }
}
```
外部控制方法监听
```dart
import 'dart:async';
import 'dart:convert';

import 'package:coal_trade/api/base_model.dart';
import 'package:coal_trade/app/environment.dart';
import 'package:get/get.dart';
import 'package:clx_webview_flutter/clx_webview_flutter.dart';

abstract class VerificationCodeManager {
  /// 发送登录验证码
  static Future<bool> sendLoginCode(String phoneNo) async {
    final result = await CaptchaUtil.generateCaptcha(
      context: Get.context!,
      uri: Config.slideVerifyUrlNew,
      onCaptchaGenerated: (message) async {
        final data = json.decode(message.message);
        final result = await fetchAsync(
          Method.post,
          url: '/trade-operation/app/public/login/captcha/send',
          params: {
            'mobile': phoneNo,
            'sceneId': data['sceneId'],
            'captchaVerifyParam': data['captchaVerifyParam'],
          },
        );
        return Future.value(result.isSuccess);
      },
    );
    return result == true;
  }
}
```

#### 获取标题
```dart
String title = customController.controller.getTitle();
```
#### 获取当前url
```dart
String currentUrl = customController.controller.getCurrentUrl();
```
#### 获取当前页面是否可以前进
```dart
bool canGoForward = customController.controller.canGoForward();
```
#### 获取当前页面是否可以后退
```dart
bool canGoBack = customController.controller.canGoBack();
```
#### 前进
```dart
customController.controller.goForward();
```
#### 后退
```dart
customController.controller.goBack();
```
#### 刷新
```dart
customController.controller.reload();
```
#### 加载url
```dart
customController.controller.loadUrl(url: Uri.parse('https://www.baidu.com'));
```