import 'dart:async';

import 'package:flutter/material.dart';

import 'result.dart';

typedef CommandCallback<T> = FutureOr<CLXResult<T>> Function();
typedef CommandBuilder<T, Argument> = FutureOr<CLXResult<T>> Function(Argument);

sealed class Command<T> extends ChangeNotifier {
  Command();

  /// 进行操作拦截
  bool _running = false;
  bool get running => _running;

  /// 处理结果
  CLXResult<T>? _result;
  CLXResult<T>? get result => _result;
  bool get fail => _result is CLXFail;
  bool get success => _result is CLXSucc;

  /// 清除最后一次执行结果
  void clearResult() {
    _result = null;
    notifyListeners();
  }

  FutureOr<dynamic> _run(CommandCallback<T> action) async {
    if (_running) return;
    _running = true;
    _result = null;

    notifyListeners();

    try {
      _result = await action();
    } catch (e) {
      _result = CLXResult.fail(Exception(e));
    } finally {
      _running = false;
      notifyListeners();
    }
    return _result;
  }
}

class CommandAction<T> extends Command<T> {
  CommandAction(this._action);

  final CommandCallback<T> _action;

  FutureOr<dynamic> run() async {
    await _run(_action);
  }
}

class CommandArgument<T, Argument> extends Command<T> {
  CommandArgument(this._action);

  final CommandBuilder<T, Argument> _action;

  FutureOr<dynamic> run(Argument argument) async {
    await _run(() => _action(argument));
  }
}
